package converter.text;

/**
 * 文字列変換処理の実装を簡略化するための抽象クラス。
 * @author Honeplus
 * @version $Id: AbstractTextConverter.java 23 2009-02-21 18:26:34Z Honeplus $
 */
public abstract class AbstractTextConverter implements TextConverter {

	/**
	 * 文字列に対して、1文字ずつの変換 {@link #convert(char)} を実施。
	 * @param s 変換元文字列
	 * @return 変換後文字列
	 */
	@Override
	public String convert(final String s) {

		// null値チェック
		if (s == null) {
			return null;	// nullはそのまま
		}
		// はじめに全文字分の領域を確保し、変換する文字だけを置き換え
		// ※ 文字数が変化する変換では、改造の必要あり。
		StringBuilder b = new StringBuilder(s);
		for (int i = 0; i < b.length(); i++) {
			b.setCharAt(i, convert(b.charAt(i)));
		}
		return b.toString();
	}
}
