package converter.text;

/**
 * 半角カナ→全角カナの変換を行うクラス。
 * @author Honeplus
 * @version $Id: HalfwidthKana2Fullwidth.java 23 2009-02-21 18:26:34Z Honeplus $
 */
public class HalfwidthKana2Fullwidth extends PropertiesMappingConverter {

	/**
	 * 半角カナ→全角カナ変換用のマッピング定義ファイル
	 *  : <code>converter/text/halfwidthKana2fullwidth.properties</code>
	 */
	private static final String HALFWIDTH_KANA_TO_FULLWIDTH_PROPERTIES
		= "converter/text/halfwidthKana2fullwidth.properties";

	/**
	 * 半角カナ→全角カナ用のプロパティファイル
	 * {@link #HALFWIDTH_KANA_TO_FULLWIDTH_PROPERTIES}
	 * をマッピングパターン定義ファイルとして読み込み、
	 * コンバーターを作成する。
     * @throws java.util.MissingResourceException プロパティファイルアクセス時エラー
	 */
	public HalfwidthKana2Fullwidth() {
		// 半角カナ→全角カナ用のプロパティファイルをマッピングパターン定義ファイルとして読み込む
		super(HALFWIDTH_KANA_TO_FULLWIDTH_PROPERTIES);
	}

	/**
	 * <p>渡されたテキストに対して、半角カナ→全角カナの変換を行う。</p>
	 * <p>万が一濁点・半濁点が余った場合、余計な点は除去する。</p>
	 * @param s 変換元テキスト
	 * @return 変換後テキスト
	 */
	@Override
	public String convert(final String s) {
		// マッピングパターンより半角カナ→全角カナの変換を行う
		String result = super.convert(s);
		// 濁点・半濁点の除去を実施して、その結果を返す
		if (result != null) {
			result = result.replaceAll("[ﾞﾟ]", "");
		}
		return result;
	}

	/**
	 * <p>（<b>未サポート</b>）1文字変換、。</p>
	 * <p>濁点などの場合、変換前後で文字数が変化するため、サポートしない。</p>
	 * @param c 変換元文字
	 * @return 変換後文字
	 * @throws UnsupportedOperationException 未サポート
	 */
	@Override
	public char convert(final char c) {
		throw new UnsupportedOperationException("not support");
	}
}
