package converter.text;

import java.io.IOException;
import java.util.Map;
import java.util.MissingResourceException;

import common.ObjectUtility;

/**
 * <p>プロパティファイルに定義されたマッピングに従い、指定されたパターンの変換を行うためのクラス。</p>
 * <p>このクラスに使用するプロパティファイルには、必ず key, value とも {@link String}
 * となるような値を持たせること。</p>
 * @author Honeplus
 * @version $Id: PropertiesMappingConverter.java 23 2009-02-21 18:26:34Z Honeplus $
 */
public class PropertiesMappingConverter extends MappingConverter {

	/** 標準のマッピングパターン定義プロパティファイル : <code>mapping.properties</code> */
	private static final String MAPPING_PROPERTIES = "mapping.properties";

	/**
	 * 指定されたプロパティファイルをマッピングパターン定義ファイルとして読み込み、
	 * コンバーターを作成する。
	 * @param name プロパティファイル名
     * @throws MissingResourceException プロパティファイルアクセス時エラー
	 */
	@SuppressWarnings("unchecked")
	public PropertiesMappingConverter(final String name) {
		// 指定されたプロパティファイルをマッピングパターン定義ファイルとして読み込む
		try {
			setMapping((Map) ObjectUtility.getProperties(name));
		} catch (IOException e) {
			// プロパティファイル読み込み中にI/Oエラー
			throw new MissingResourceException(e.getMessage(), name, "");
		} catch (IllegalArgumentException e) {
			// プロパティファイルのフォーマットが不正
			throw new MissingResourceException(e.getMessage(), name, "");
		} catch (NullPointerException e) {
			// プロパティファイルがない
			throw new MissingResourceException(e.getMessage(), name, "");
		}
	}

	/**
	 * 標準のプロパティファイル {@link #MAPPING_PROPERTIES}
	 * をマッピングパターン定義ファイルとして読み込み、
	 * コンバーターを作成する。
     * @throws MissingResourceException プロパティファイルアクセス時エラー
	 */
	public PropertiesMappingConverter() {
		// 標準のプロパティファイルをマッピングパターン定義ファイルとして読み込む
		this(MAPPING_PROPERTIES);
	}
}
