package common;

import static org.junit.Assert.*;

import org.junit.Test;

/**
 * {@link HiddenAccessor} のJUnitテストクラス。
 * @author Honeplus
 * @version $Id: HiddenAccessorTest.java 33 2009-03-01 16:29:40Z Honeplus $
 */
public class HiddenAccessorTest {

	/** テスト用の仮クラス */
	private static final class Foo {
		/**
		 * テスト用非公開コンストラクタ。
		 */
		private Foo() { }
		/**
		 * テスト用非公開戻り値メソッド。
		 * @param s 入力値
		 * @return 変換した値
		 */
		private String convert(final String s) {
			return s.replace("input-", "output-");
		}
	}

	/** テスト用の仮クラス */
	private static final class Bar {
		/** テスト用非公開フィールド */
		private int num;
		/**
		 * テスト用非公開コンストラクタ。
		 * @param i 入力値
		 */
		private Bar(final int i) {
			num = i;
		}
		/**
		 * 公開ゲッター。
		 * @return num
		 */
		public int getNum() {
			return num;
		}
	}

	/** テスト用の仮クラス */
	private static final class Baz {
		/**
		 * テスト用非公開コンストラクタ。
		 */
		private Baz() { }
		/** テスト用非公開フィールド */
		private int status;
		/**
		 * テスト用非公開更新メソッド。
		 * @param i 入力値
		 * @param s 入力値ダミー
		 */
		private void work(final int i, final String s) {
			status = i;
		}
	}

	/** テスト用の仮クラス */
	private static class FooBar {
		/**
		 * テスト用非公開コンストラクタ。
		 */
		public FooBar() { }
		/** テスト用非公開フィールド */
		private int result;
		/**
		 * テスト用非公開戻り値メソッド。
		 */
		public void run() {
			result = -1;
		}
	}

	/**
	 * {@link HiddenAccessor}
	 * のテスト・メソッド（メソッドの一連の動作）。
	 * @throws Throwable テスト失敗
	 */
	@Test
	public void testInvokeFull() throws Throwable {
		HiddenAccessor acc = new HiddenAccessor(Foo.class);
		acc.setMethod("convert", String.class);
		assertEquals("output-string", acc.invoke("input-string"));
	}
	/**
	 * {@link HiddenAccessor}
	 * のテスト・メソッド（コンストラクタの一連の動作）。
	 * @throws Throwable テスト失敗
	 */
	@Test
	public void testNewInstanceFull() throws Throwable {
		HiddenAccessor acc = new HiddenAccessor(Bar.class);
		acc.setConstructor(int.class);
		acc.newInstance(10);
		assertEquals(10, acc.getField("num"));
	}

	/**
	 * {@link HiddenAccessor}
	 * のテスト・メソッド（コンストラクタの一連の動作2）。
	 * @throws Throwable テスト失敗
	 */
	@Test
	public void testNewInstanceFull2() throws Throwable {
		// テストとしては↑と同じ、Javadocマニュアルの構文確認
		HiddenAccessor acc = new HiddenAccessor(Bar.class);
		acc.setConstructor(int.class);
		assertEquals(10, ((Bar) acc.newInstance(10)).getNum());
	}

	/**
	 * {@link HiddenAccessor}
	 * のテスト・メソッド（フィールドアクセスの一連の動作）。
	 * @throws Throwable テスト失敗
	 */
	@Test
	public void testSetFieldFull() throws Throwable {
		HiddenAccessor acc = new HiddenAccessor(Baz.class);
		acc.setField("status", 3);
		acc.setMethod("work", int.class, String.class);
		acc.invoke(10, "update");
		assertEquals(10, acc.getField("status"));
	}

	/**
	 * {@link HiddenAccessor}
	 * のテスト・メソッド（フィールドアクセスの一連の動作2）。
	 * @throws Throwable テスト失敗
	 */
	@Test
	public void testGetFieldFull() throws Throwable {
		FooBar f = new FooBar();
		f.run();
		HiddenAccessor acc = new HiddenAccessor(FooBar.class);
		acc.setInstance(f);
		assertEquals(-1, acc.getField("result"));
	}

	//TODO: テストケースが大量に不足
}
