package converter.text;

import static org.junit.Assert.*;

import java.util.HashMap;
import java.util.Map;
import java.util.LinkedHashMap;

import org.junit.Test;

import common.HiddenAccessor;

/**
 * {@link MappingRegexConverter} のJUnitテストクラス。
 * @author Honeplus
 * @version $Id: MappingRegexConverterTest.java 32 2009-03-01 13:59:59Z Honeplus $
 */
public class MappingRegexConverterTest {

	/**
	 * {@link MappingRegexConverter#convert(java.lang.String)}
	 * のテスト・メソッド。
	 */
	@Test
	public void testConvertString() {
		Map<String, String> map = new LinkedHashMap<String, String>();
		map.put("a", "b");
		map.put("[2-5]", "*");
		map.put("\\[.*?\\]", "[deleted]");
		MappingRegexConverter conv = new MappingRegexConverter(map);
		assertEquals("bbcdefgbbcdef", conv.convert("abcdefgabcdef"));
		assertEquals("bbc01****6789あ", conv.convert("abc0123456789あ"));
		assertEquals("例[deleted][deleted]？", conv.convert("例[テスト][テスト2]？"));
	}

	/**
	 * {@link MappingRegexConverter#convert(char)}
	 * のテスト・メソッド。
	 */
	@Test(expected = UnsupportedOperationException.class)
	public void testConvertChar() {
		// 未サポートのエラーとなること
		new MappingRegexConverter(new HashMap<String, String>()).convert('a');
	}

	/**
	 * {@link MappingRegexConverter#MappingRegexConverter(java.util.Map)}
	 * のテスト・メソッド。
	 */
	@Test
	public void testMappingRegexConverterMapOfStringString() {
		// 指定した mapping が設定されたオブジェクトが生成されること
		Map<String, String> map = new LinkedHashMap<String, String>();
		map.put("test", "test2");
		HiddenAccessor acc = new HiddenAccessor(MappingConverter.class);
		acc.setInstance(new MappingRegexConverter(map));
		assertSame(map, acc.getField("mapping"));
	}

	/**
	 * {@link MappingRegexConverter#MappingRegexConverter()}
	 * のテスト・メソッド。
	 * @throws Throwable テスト失敗
	 */
	@Test
	public void testMappingRegexConverter() throws Throwable {
		// mappingが未設定のオブジェクトが生成されること
		HiddenAccessor acc = new HiddenAccessor(MappingConverter.class);
		acc.setInstance(new MappingRegexConverter());
		assertNull(acc.getField("mapping"));
	}
}
