package converter.text;

import static org.junit.Assert.*;

import java.util.ArrayList;
import java.util.List;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;
import org.junit.runners.Parameterized.Parameters;

/**
 * {@link TextConvertUtility} のJUnitテストクラス
 * （パラメータでの正常系のパターンテスト）。
 * @author Honeplus
 * @version $Id: TextConvertUtilityTestSuccessPattern.java 26 2009-02-22 17:43:14Z Honeplus $
 */
@RunWith(Parameterized.class)
public class TextConvertUtilityTestSuccessPattern {

	/**
	 * テストパラメータ用変数 : {@link TextConvertUtility#convert} の <var>text</var>
	 */
	private String text;
	/**
	 * テストパラメータ用変数 : {@link TextConvertUtility#convert} の <var>runType</var>
	 */
	private TextConvertUtility.RunType runType;
	/**
	 * テストパラメータ用変数 : {@link TextConvertUtility#convert} の実行結果期待値
	 */
	private String expected;

	/**
	 * テストパラメータ用コンストラクタ。<br>
	 * パラメータ指定した値がコンストラクタの引数に渡される。
	 * @param data {@link TextConvertUtility#convert} の <var>text</var>
	 * @param type 〃 の <var>runType</var>
	 * @param value 期待値
	 */
	public TextConvertUtilityTestSuccessPattern(final String value,
			final String data, final TextConvertUtility.RunType type) {
		this.text = data;
		this.runType = type;
		this.expected = value;
	}

	/**
	 * テストパラメータ指定。
	 * @return パラメータ
	 */
	@Parameters
	public static List<Object[]> parameter() {
		List<Object[]> list = new ArrayList<Object[]>();
		// ここで指定した値がインスタンス生成時の引数として渡される
		// 空文字列
		list.add(new Object[]{"", "", TextConvertUtility
				.RunType.FULLWIDTH_NUMBER_TO_HALFWIDTH});
		// スペースのみ変換なし文字列
		list.add(new Object[]{"  ", "  ", TextConvertUtility
				.RunType.FULLWIDTH_NUMBER_TO_HALFWIDTH});
		// 全角数値→半角数値（null値）
		list.add(new Object[]{null, null, TextConvertUtility
				.RunType.FULLWIDTH_NUMBER_TO_HALFWIDTH});
		// 全角数値→半角数値（各種文字）
		list.add(new Object[]{
				"012abcABC.+-012ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇",
				"012abcABC.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇",
				TextConvertUtility.RunType.FULLWIDTH_NUMBER_TO_HALFWIDTH});
		// 全角数値→半角数値（数値パターン）
		list.add(new Object[]{
				"0123456789",
				"０１２３４５６７８９",
				TextConvertUtility.RunType.FULLWIDTH_NUMBER_TO_HALFWIDTH});
		// 全角英字→半角英字（null値）
		list.add(new Object[]{null, null, TextConvertUtility
				.RunType.FULLWIDTH_LATIN_TO_HALFWIDTH});
		// 全角英字→半角英字（各種文字）
		list.add(new Object[]{
				"012abcABC.+-０１２abcABC．＋－あいうｱｲｳアイウ亜伊宇",
				"012abcABC.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇",
				TextConvertUtility.RunType.FULLWIDTH_LATIN_TO_HALFWIDTH});
		// 全角英字→半角英字（英字パターン）
		list.add(new Object[]{
				"abcdefghijklmnopqrstuvwxyz"
				+ "ABCDEFGHIJKLMNOPQRSTUVWXYZ",
				"ａｂｃｄｅｆｇｈｉｊｋｌｍｎｏｐｑｒｓｔｕｖｗｘｙｚ"
				+ "ＡＢＣＤＥＦＧＨＩＪＫＬＭＮＯＰＱＲＳＴＵＶＷＸＹＺ",
				TextConvertUtility.RunType.FULLWIDTH_LATIN_TO_HALFWIDTH});
		// 全角英数→半角英数（null値）
		list.add(new Object[]{null, null, TextConvertUtility
				.RunType.FULLWIDTH_LATIN_AND_NUMBER_TO_HALFWIDTH});
		// 全角英数→半角英数（各種文字）
		list.add(new Object[]{
				"012abcABC.+-012abcABC．＋－あいうｱｲｳアイウ亜伊宇",
				"012abcABC.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇",
				TextConvertUtility
					.RunType.FULLWIDTH_LATIN_AND_NUMBER_TO_HALFWIDTH});
		// 全角記号→半角記号（null値）
		list.add(new Object[]{null, null, TextConvertUtility
				.RunType.FULLWIDTH_MARK_TO_HALFWIDTH});
		// 全角記号→半角記号（各種文字）
		list.add(new Object[]{
				"012abcABC.+-０１２ａｂｃＡＢＣ.+-あいうｱｲｳアイウ亜伊宇",
				"012abcABC.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇",
				TextConvertUtility.RunType.FULLWIDTH_MARK_TO_HALFWIDTH});
		// 全角記号→半角記号（記号パターン）
		list.add(new Object[]{
				"!\"#$%&'()*+.-/:;>=<?@[\\]^_`{|}~ ",
				"！”＃＄％＆’（）＊＋．－／：；＞＝＜？＠［￥］＾＿‘｛｜｝～　",
				TextConvertUtility.RunType.FULLWIDTH_MARK_TO_HALFWIDTH});
		// 全角英数記号→半角英数記号（null値）
		list.add(new Object[]{null, null, TextConvertUtility
				.RunType.FULLWIDTH_LATIN_AND_NUMBER_AND_MARK_TO_HALFWIDTH});
		// 全角英数記号→半角英数記号（各種文字）
		list.add(new Object[]{
				"012abcABC.+-012abcABC.+-あいうｱｲｳアイウ亜伊宇",
				"012abcABC.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇",
				TextConvertUtility
					.RunType.FULLWIDTH_LATIN_AND_NUMBER_AND_MARK_TO_HALFWIDTH});
		// 全角カナ→半角カナ（null値）
		list.add(new Object[]{null, null, TextConvertUtility
				.RunType.FULLWIDTH_KANA_TO_HALFWIDTH});
		// 全角カナ→半角カナ（各種文字）
		list.add(new Object[]{
				"012abcABC.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳｱｲｳ亜伊宇",
				"012abcABC.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇",
				TextConvertUtility.RunType.FULLWIDTH_KANA_TO_HALFWIDTH});
		// 全角カナ→半角カナ（カナパターン）
		list.add(new Object[]{
				"ｱｲｳｴｵｶｷｸｹｺｻｼｽｾｿﾀﾁﾂﾃﾄﾅﾆﾇﾈﾉﾊﾋﾌﾍﾎﾏﾐﾑﾒﾓﾔﾕﾖﾗﾘﾙﾚﾛﾜｦﾝ"
				+ "ｧｨｩｪｫｯｬｭｮ"
				+ "ｶﾞｷﾞｸﾞｹﾞｺﾞｻﾞｼﾞｽﾞｾﾞｿﾞﾀﾞﾁﾞﾂﾞﾃﾞﾄﾞﾊﾞﾋﾞﾌﾞﾍﾞﾎﾞｳﾞﾜﾞﾊﾟﾋﾟﾌﾟﾍﾟﾎﾟ"
				+ "｡｢｣､･",
				"アイウエオカキクケコサシスセソタチツテトナニヌネノ"
				+ "ハヒフヘホマミムメモヤユヨラリルレロワヲン"
				+ "ァィゥェォッャュョ"
				+ "ガギグゲゴザジズゼゾダヂヅデドバビブベボヴヷパピプペポ"
				+ "。「」、・",
				TextConvertUtility.RunType.FULLWIDTH_KANA_TO_HALFWIDTH});
		// 全角→半角（可能なもの全て）（null値）
		list.add(new Object[]{null, null, TextConvertUtility
				.RunType.FULLWIDTH_TO_HALFWIDTH});
		// 全角→半角（可能なもの全て）（各種文字）
		list.add(new Object[]{
				"012abcABC.+-012abcABC.+-あいうｱｲｳｱｲｳ亜伊宇",
				"012abcABC.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇",
				TextConvertUtility.RunType.FULLWIDTH_TO_HALFWIDTH});
		// 半角数値→全角数値（null値）
		list.add(new Object[]{null, null, TextConvertUtility
				.RunType.HALFWIDTH_NUMBER_TO_FULLWIDTH});
		// 半角数値→全角数値（各種文字）
		list.add(new Object[]{
				"０１２abcABC.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇",
				"012abcABC.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇",
				TextConvertUtility.RunType.HALFWIDTH_NUMBER_TO_FULLWIDTH});
		// 半角数値→全角数値（数値パターン）
		list.add(new Object[]{
				"０１２３４５６７８９",
				"0123456789",
				TextConvertUtility.RunType.HALFWIDTH_NUMBER_TO_FULLWIDTH});
		// 半角英字→全角英字（null値）
		list.add(new Object[]{null, null, TextConvertUtility
				.RunType.HALFWIDTH_LATIN_TO_FULLWIDTH});
		// 半角英字→全角英字（各種文字）
		list.add(new Object[]{
				"012ａｂｃＡＢＣ.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇",
				"012abcABC.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇",
				TextConvertUtility.RunType.HALFWIDTH_LATIN_TO_FULLWIDTH});
		// 半角英字→全角英字（英字パターン）
		list.add(new Object[]{
				"ａｂｃｄｅｆｇｈｉｊｋｌｍｎｏｐｑｒｓｔｕｖｗｘｙｚ"
				+ "ＡＢＣＤＥＦＧＨＩＪＫＬＭＮＯＰＱＲＳＴＵＶＷＸＹＺ",
				"abcdefghijklmnopqrstuvwxyz"
				+ "ABCDEFGHIJKLMNOPQRSTUVWXYZ",
				TextConvertUtility.RunType.HALFWIDTH_LATIN_TO_FULLWIDTH});
		// 半角英数→全角英数（null値）
		list.add(new Object[]{null, null, TextConvertUtility
				.RunType.HALFWIDTH_LATIN_AND_NUMBER_TO_FULLWIDTH});
		// 半角英数→全角英数（各種文字）
		list.add(new Object[]{
				"０１２ａｂｃＡＢＣ.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇",
				"012abcABC.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇",
				TextConvertUtility
					.RunType.HALFWIDTH_LATIN_AND_NUMBER_TO_FULLWIDTH});
		// 半角記号→全角記号（null値）
		list.add(new Object[]{null, null, TextConvertUtility
				.RunType.HALFWIDTH_MARK_TO_FULLWIDTH});
		// 半角記号→全角記号（各種文字）
		list.add(new Object[]{
				"012abcABC．＋－０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇",
				"012abcABC.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇",
				TextConvertUtility.RunType.HALFWIDTH_MARK_TO_FULLWIDTH});
		// 半角記号→全角記号（記号パターン）
		list.add(new Object[]{
				"！”＃＄％＆’（）＊＋．－／：；＞＝＜？＠［￥］＾＿‘｛｜｝～　",
				"!\"#$%&'()*+.-/:;>=<?@[\\]^_`{|}~ ",
				TextConvertUtility.RunType.HALFWIDTH_MARK_TO_FULLWIDTH});
		// 半角英数記号→全角英数記号（null値）
		list.add(new Object[]{null, null, TextConvertUtility
				.RunType.HALFWIDTH_LATIN_AND_NUMBER_AND_MARK_TO_FULLWIDTH});
		// 半角英数記号→全角英数記号（各種文字）
		list.add(new Object[]{
				"０１２ａｂｃＡＢＣ．＋－０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇",
				"012abcABC.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇",
				TextConvertUtility
					.RunType.HALFWIDTH_LATIN_AND_NUMBER_AND_MARK_TO_FULLWIDTH});
		// 半角カナ→全角カナ（null値）
		list.add(new Object[]{null, null, TextConvertUtility
				.RunType.HALFWIDTH_KANA_TO_FULLWIDTH});
		// 半角カナ→全角カナ（各種文字）
		list.add(new Object[]{
				"012abcABC.+-０１２ａｂｃＡＢＣ．＋－あいうアイウアイウ亜伊宇",
				"012abcABC.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇",
				TextConvertUtility.RunType.HALFWIDTH_KANA_TO_FULLWIDTH});
		// 半角カナ→全角カナ（カナパターン）
		list.add(new Object[]{
				"アイウエオカキクケコサシスセソタチツテトナニヌネノ"
				+ "ハヒフヘホマミムメモヤユヨラリルレロワヲン"
				+ "ァィゥェォッャュョ"
				+ "ガギグゲゴザジズゼゾダヂヅデドバビブベボヴヷパピプペポ"
				+ "。「」、・",
				"ｱｲｳｴｵｶｷｸｹｺｻｼｽｾｿﾀﾁﾂﾃﾄﾅﾆﾇﾈﾉﾊﾋﾌﾍﾎﾏﾐﾑﾒﾓﾔﾕﾖﾗﾘﾙﾚﾛﾜｦﾝ"
				+ "ｧｨｩｪｫｯｬｭｮ"
				+ "ｶﾞｷﾞｸﾞｹﾞｺﾞｻﾞｼﾞｽﾞｾﾞｿﾞﾀﾞﾁﾞﾂﾞﾃﾞﾄﾞﾊﾞﾋﾞﾌﾞﾍﾞﾎﾞｳﾞﾜﾞﾊﾟﾋﾟﾌﾟﾍﾟﾎﾟ"
				+ "｡｢｣､･",
				TextConvertUtility.RunType.HALFWIDTH_KANA_TO_FULLWIDTH});
		// 半角カナ→全角カナ（カナごみ濁点の除去）
		list.add(new Object[]{
				"ガギグゲゴパピプペポ",
				"ｶﾞｷﾞﾞｸﾞｹﾞｺﾞﾊﾟﾋﾟﾌﾟﾟﾟﾍﾟﾎﾟ",
				TextConvertUtility.RunType.HALFWIDTH_KANA_TO_FULLWIDTH});
		// 半角→全角（可能なもの全て）（null値）
		list.add(new Object[]{null, null, TextConvertUtility
				.RunType.HALFWIDTH_TO_FULLWIDTH});
		// 半角→全角（可能なもの全て）（各種文字）
		list.add(new Object[]{
				"０１２ａｂｃＡＢＣ．＋－０１２ａｂｃＡＢＣ．＋－あいうアイウアイウ亜伊宇",
				"012abcABC.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇",
				TextConvertUtility.RunType.HALFWIDTH_TO_FULLWIDTH});
		// ひらがな→カタカナ（null値）
		list.add(new Object[]{null, null, TextConvertUtility
				.RunType.HIRAGANA_TO_KATAKANA});
		// ひらがな→カタカナ（各種文字）
		list.add(new Object[]{
				"012abcABC.+-０１２ａｂｃＡＢＣ．＋－アイウｱｲｳアイウ亜伊宇",
				"012abcABC.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇",
				TextConvertUtility.RunType.HIRAGANA_TO_KATAKANA});
		// ひらがな→カタカナ（パターン）
		list.add(new Object[]{
				"アイウエオカキクケコサシスセソタチツテトナニヌネノ"
				+ "ハヒフヘホマミムメモヤユヨラリルレロワヲン"
				+ "ァィゥェォッャュョ"
				+ "ガギグゲゴザジズゼゾダヂヅデドバビブベボパピプペポ",
				"あいうえおかきくけこさしすせそたちつてとなにぬねの"
				+ "はひふへほまみむめもやゆよらりるれろわをん"
				+ "ぁぃぅぇぉっゃゅょ"
				+ "がぎぐげござじずぜぞだぢづでどばびぶべぼぱぴぷぺぽ",
				TextConvertUtility.RunType.HIRAGANA_TO_KATAKANA});
		// カタカナ→ひらがな（null値）
		list.add(new Object[]{null, null, TextConvertUtility
				.RunType.KATAKANA_TO_HIRAGANA});
		// カタカナ→ひらがな（各種文字）
		list.add(new Object[]{
				"012abcABC.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳあいう亜伊宇",
				"012abcABC.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇",
				TextConvertUtility.RunType.KATAKANA_TO_HIRAGANA});
		// カタカナ→ひらがな（パターン）
		list.add(new Object[]{
				"あいうえおかきくけこさしすせそたちつてとなにぬねの"
				+ "はひふへほまみむめもやゆよらりるれろわをん"
				+ "ぁぃぅぇぉっゃゅょ"
				+ "がぎぐげござじずぜぞだぢづでどばびぶべぼぱぴぷぺぽ",
				"アイウエオカキクケコサシスセソタチツテトナニヌネノ"
				+ "ハヒフヘホマミムメモヤユヨラリルレロワヲン"
				+ "ァィゥェォッャュョ"
				+ "ガギグゲゴザジズゼゾダヂヅデドバビブベボパピプペポ",
				TextConvertUtility.RunType.KATAKANA_TO_HIRAGANA});
		// ローマ数字→似た半角英字文字列（IやV等への変換）（null値）
		list.add(new Object[]{null, null, TextConvertUtility
				.RunType.ROMAN_NUMERALS_TO_HALFWIDTH});
		// ローマ数字→似た半角英字文字列（IやV等への変換）（各種文字）
		list.add(new Object[]{
				"012abcABC.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇I①⑴",
				"012abcABC.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇Ⅰ①⑴",
				TextConvertUtility.RunType.ROMAN_NUMERALS_TO_HALFWIDTH});
		// ローマ数字→似た半角英字文字列（IやV等への変換）（パターン）
		list.add(new Object[]{
				"IIIIIIIVVVIVIIVIIIIXXXIXIILCDM"
				+ "iiiiiiivvviviiviiiixxxixiilcdm"
				+ "ↀↁↂↃ",	// 変換されないローマ数字
				"ⅠⅡⅢⅣⅤⅥⅦⅧⅨⅩⅪⅫⅬⅭⅮⅯⅰⅱⅲⅳⅴⅵⅶⅷⅸⅹⅺⅻⅼⅽⅾⅿↀↁↂↃ",
				TextConvertUtility.RunType.ROMAN_NUMERALS_TO_HALFWIDTH});
		// 丸囲み数字→似た半角英数文字列（(1)等への変換）（null値）
		list.add(new Object[]{null, null, TextConvertUtility
				.RunType.ENCIRCLED_NUMBER_HALFWIDTH});
		// 丸囲み数字→似た半角英数文字列（(1)等への変換）（各種文字）
		list.add(new Object[]{
				"012abcABC.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇Ⅰ(1)⑴",
				"012abcABC.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇Ⅰ①⑴",
				TextConvertUtility.RunType.ENCIRCLED_NUMBER_HALFWIDTH});
		// 丸囲み数字→似た半角英数文字列（(1)等への変換）（パターン）
		list.add(new Object[]{
				"(1)(2)(3)(4)(5)(6)(7)(8)(9)(10)(11)(12)(13)(14)(15)"
				+ "(16)(17)(18)(19)(20)(21)(22)(23)(24)(25)(26)(27)(28)(29)(30)"
				+ "(31)(32)(33)(34)(35)(36)(37)(38)(39)(40)(41)(42)(43)(44)(45)"
				+ "(46)(47)(48)(49)(50)"
				+ "(1)(2)(3)(4)(5)(6)(7)(8)(9)(10)(11)(12)(13)(14)(15)"
				+ "(16)(17)(18)(19)(20)(1)(2)(3)(4)(5)(6)(7)(8)(9)(10)",
				"①②③④⑤⑥⑦⑧⑨⑩⑪⑫⑬⑭⑮⑯⑰⑱⑲⑳㉑㉒㉓㉔㉕㉖㉗㉘㉙㉚"
				+ "㉛㉜㉝㉞㉟㊱㊲㊳㊴㊵㊶㊷㊸㊹㊺㊻㊼㊽㊾㊿"
				+ "❶❷❸❹❺❻❼❽❾❿⓫⓬⓭⓮⓯⓰⓱⓲⓳⓴⓵⓶⓷⓸⓹⓺⓻⓼⓽⓾",
				TextConvertUtility.RunType.ENCIRCLED_NUMBER_HALFWIDTH});
		// ローマ数字・丸数字→似た半角英数文字列（Iや(1)への変換）（null値）
		list.add(new Object[]{null, null, TextConvertUtility
				.RunType.ROMAN_AND_ENCIRCLED_HALFWIDTH});
		// ローマ数字・丸数字→似た半角英数文字列（Iや(1)への変換）（各種文字）
		list.add(new Object[]{
				"012abcABC.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇I(1)⑴",
				"012abcABC.+-０１２ａｂｃＡＢＣ．＋－あいうｱｲｳアイウ亜伊宇Ⅰ①⑴",
				TextConvertUtility.RunType.ROMAN_AND_ENCIRCLED_HALFWIDTH});
		return list;
	}

	/**
	 * {@link TextConvertUtility#convert(String, TextConvertUtility.RunType)}
	 * のためのテスト・メソッド。
	 */
	@Test
	public void testConvert() {
		assertEquals(this.expected,
				TextConvertUtility.convert(this.text, this.runType));
	}
}
